import React, { useEffect, useState } from 'react';

const LandDetails = ({ onDataUpdate, initialData = {} }) => {
  const [formData, setFormData] = useState({
    distanceFromAirport: initialData.distanceFromAirport || '',
    distanceFromRailway: initialData.distanceFromRailway || '',
    distanceFromBusStand: initialData.distanceFromBusStand || '',
    distanceFromHospital: initialData.distanceFromHospital || '',
    distanceFromSchool: initialData.distanceFromSchool || '',
    roadTouch: initialData.roadTouch || '',
    plotFacing: initialData.plotFacing || ''
  });


  /*useEffect(() => {
    onDataUpdate({
      roadTouch: formData.roadTouch,
      plotFacing: formData.plotFacing,
      distanceFromAirport: formData.distanceFromAirport,
      distanceFromRailway: formData.distanceFromRailway,
      distanceFromBusStand: formData.distanceFromBusStand,
      distanceFromHospital: formData.distanceFromHospital,
      distanceFromSchool: formData.distanceFromSchool
    });
  }, [formData, onDataUpdate]); */

  useEffect(() => {
    console.log('LandDetails updating with:', formData); // Add this log
    onDataUpdate(formData);
  }, [formData, onDataUpdate]);
  
  



  /*const handleInputChange = (field, value) => {
    setFormData(prev => ({
      ...prev,
      [field]: value
    }));
  }; */

  const handleInputChange = (field, value) => {
    console.log(`Updating ${field} with value:`, value); // Add this log
    setFormData(prev => ({
      ...prev,
      [field]: value
    }));
  };
  

  

  const distanceItems = [
    { icon: "✈️", label: "Airport", field: "distanceFromAirport" },
    { icon: "🚂", label: "Railway", field: "distanceFromRailway" },
    { icon: "🚌", label: "Bus Stand", field: "distanceFromBusStand" },
    { icon: "🏥", label: "Hospital", field: "distanceFromHospital" },
    { icon: "🏫", label: "School", field: "distanceFromSchool" }
  ];

  return (
    <div className="w-full space-y-6">
      <div className="space-y-4">
        <div>
          <label className="block text-sm font-medium text-gray-700 mb-2">
            Road Touch
          </label>
          <select
            value={formData.roadTouch}
            onChange={(e) => handleInputChange('roadTouch', e.target.value)}
            className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
          >
            <option value="">Select Road Type</option>
            <option value="Expressway">Expressway</option>
            <option value="Highway">Highway</option>
            <option value="Main Road">Main Road</option>
            <option value="Internal Road">Internal Road</option>
          </select>
        </div>
        <div>
          <label className="block text-sm font-medium text-gray-700 mb-2">
            Plot Facing
          </label>
          <select
            value={formData.plotFacing}
            onChange={(e) => handleInputChange('plotFacing', e.target.value)}
            className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none sm:px-4 sm:py-2.5"
          >
            <option value="">Select Facing</option>
            <option value="East">East</option>
            <option value="West">West</option>
            <option value="North">North</option>
            <option value="South">South</option>
          </select>
        </div>
        <div className="space-y-4">
          <label className="block text-sm font-medium text-gray-700">
            Distance From
          </label>
          <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
            {distanceItems.map((item) => (
              <div key={item.field} className="flex items-center space-x-3">
                <span className="text-xl">{item.icon}</span>
                <div className="flex-1">
                  <label className="block text-sm text-gray-600 mb-1">
                    {item.label}
                  </label>
                  <input
                    type="text"
                    value={formData[item.field]}
                    onChange={(e) => handleInputChange(item.field, e.target.value)}
                    placeholder={`Distance to ${item.label}`}
                    className="w-full rounded-lg border border-gray-300 bg-transparent px-3 py-2 text-sm focus:border-purple-600 focus:outline-none"
                  />
                </div>
              </div>
            ))}
          </div>
        </div>
      </div>
    </div>
  );
};

export default LandDetails;